@@ -2,7 +2,7 @@ from .resource_publisher import ResourcePublisher, UpdatePolicy
 from .resource import Resource
 
 from .single_resource import SingleResource
-from .client_resource import SingleClientResource
+from .client_resource import SingleClientResource, ClientManager, ClientRoleManager, ClientRoleResource
 from .custom_authentication_resource import SingleCustomAuthenticationResource
 from .role_resource import RoleResource
 from .client_scope_resource import ClientScopeResource
